@@ -3,6 +3,7 @@ use byteorder::{ReadBytesExt, WriteBytesExt, BigEndian};
 use fallible_iterator::FallibleIterator;
 use std::error::Error;
 use std::str;
+use std::boxed::Box as StdBox;
 
 use {Oid, IsNull, write_nullable, FromUsize};
 
@@ -20,7 +21,7 @@ pub fn bool_to_sql(v: bool, buf: &mut Vec<u8>) {
 
 /// Deserializes a `BOOL` value.
 #[inline]
-pub fn bool_from_sql(buf: &[u8]) -> Result<bool, Box<Error + Sync + Send>> {
+pub fn bool_from_sql(buf: &[u8]) -> Result<bool, StdBox<Error + Sync + Send>> {
     if buf.len() != 1 {
         return Err("invalid buffer size".into());
     }
@@ -48,8 +49,8 @@ pub fn text_to_sql(v: &str, buf: &mut Vec<u8>) {
 
 /// Deserializes a `TEXT`, `VARCHAR`, `CHAR(n)`, `NAME`, or `CITEXT` value.
 #[inline]
-pub fn text_from_sql(buf: &[u8]) -> Result<&str, Box<Error + Sync + Send>> {
-    Ok(try!(str::from_utf8(buf)))
+pub fn text_from_sql(buf: &[u8]) -> Result<&str, StdBox<Error + Sync + Send>> {
+    Ok(str::from_utf8(buf)?)
 }
 
 /// Serializes a `"char"` value.
@@ -60,8 +61,8 @@ pub fn char_to_sql(v: i8, buf: &mut Vec<u8>) {
 
 /// Deserializes a `"char"` value.
 #[inline]
-pub fn char_from_sql(mut buf: &[u8]) -> Result<i8, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i8());
+pub fn char_from_sql(mut buf: &[u8]) -> Result<i8, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i8()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -76,8 +77,8 @@ pub fn int2_to_sql(v: i16, buf: &mut Vec<u8>) {
 
 /// Deserializes an `INT2` value.
 #[inline]
-pub fn int2_from_sql(mut buf: &[u8]) -> Result<i16, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i16::<BigEndian>());
+pub fn int2_from_sql(mut buf: &[u8]) -> Result<i16, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i16::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -92,8 +93,8 @@ pub fn int4_to_sql(v: i32, buf: &mut Vec<u8>) {
 
 /// Deserializes an `INT4` value.
 #[inline]
-pub fn int4_from_sql(mut buf: &[u8]) -> Result<i32, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i32::<BigEndian>());
+pub fn int4_from_sql(mut buf: &[u8]) -> Result<i32, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i32::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -108,8 +109,8 @@ pub fn oid_to_sql(v: Oid, buf: &mut Vec<u8>) {
 
 /// Deserializes an `OID` value.
 #[inline]
-pub fn oid_from_sql(mut buf: &[u8]) -> Result<Oid, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_u32::<BigEndian>());
+pub fn oid_from_sql(mut buf: &[u8]) -> Result<Oid, StdBox<Error + Sync + Send>> {
+    let v = buf.read_u32::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -124,8 +125,8 @@ pub fn int8_to_sql(v: i64, buf: &mut Vec<u8>) {
 
 /// Deserializes an `INT8` value.
 #[inline]
-pub fn int8_from_sql(mut buf: &[u8]) -> Result<i64, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i64::<BigEndian>());
+pub fn int8_from_sql(mut buf: &[u8]) -> Result<i64, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i64::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -140,8 +141,8 @@ pub fn float4_to_sql(v: f32, buf: &mut Vec<u8>) {
 
 /// Deserializes a `FLOAT4` value.
 #[inline]
-pub fn float4_from_sql(mut buf: &[u8]) -> Result<f32, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_f32::<BigEndian>());
+pub fn float4_from_sql(mut buf: &[u8]) -> Result<f32, StdBox<Error + Sync + Send>> {
+    let v = buf.read_f32::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -156,8 +157,8 @@ pub fn float8_to_sql(v: f64, buf: &mut Vec<u8>) {
 
 /// Deserializes a `FLOAT8` value.
 #[inline]
-pub fn float8_from_sql(mut buf: &[u8]) -> Result<f64, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_f64::<BigEndian>());
+pub fn float8_from_sql(mut buf: &[u8]) -> Result<f64, StdBox<Error + Sync + Send>> {
+    let v = buf.read_f64::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid buffer size".into());
     }
@@ -166,8 +167,9 @@ pub fn float8_from_sql(mut buf: &[u8]) -> Result<f64, Box<Error + Sync + Send>>
 
 /// Serializes an `HSTORE` value.
 #[inline]
-pub fn hstore_to_sql<'a, I>(values: I, buf: &mut Vec<u8>) -> Result<(), Box<Error + Sync + Send>>
-    where I: IntoIterator<Item = (&'a str, Option<&'a str>)>
+pub fn hstore_to_sql<'a, I>(values: I, buf: &mut Vec<u8>) -> Result<(), StdBox<Error + Sync + Send>>
+where
+    I: IntoIterator<Item = (&'a str, Option<&'a str>)>,
 {
     let base = buf.len();
     buf.extend_from_slice(&[0; 4]);
@@ -176,24 +178,26 @@ pub fn hstore_to_sql<'a, I>(values: I, buf: &mut Vec<u8>) -> Result<(), Box<Erro
     for (key, value) in values {
         count += 1;
 
-        try!(write_pascal_string(key, buf));
+        write_pascal_string(key, buf)?;
 
         match value {
             Some(value) => {
-                try!(write_pascal_string(value, buf));
+                write_pascal_string(value, buf)?;
             }
             None => buf.write_i32::<BigEndian>(-1).unwrap(),
         }
     }
 
-    let count = try!(i32::from_usize(count));
-    (&mut buf[base..base + 4]).write_i32::<BigEndian>(count).unwrap();
+    let count = i32::from_usize(count)?;
+    (&mut buf[base..base + 4])
+        .write_i32::<BigEndian>(count)
+        .unwrap();
 
     Ok(())
 }
 
-fn write_pascal_string(s: &str, buf: &mut Vec<u8>) -> Result<(), Box<Error + Sync + Send>> {
-    let size = try!(i32::from_usize(s.len()));
+fn write_pascal_string(s: &str, buf: &mut Vec<u8>) -> Result<(), StdBox<Error + Sync + Send>> {
+    let size = i32::from_usize(s.len())?;
     buf.write_i32::<BigEndian>(size).unwrap();
     buf.extend_from_slice(s.as_bytes());
     Ok(())
@@ -201,9 +205,10 @@ fn write_pascal_string(s: &str, buf: &mut Vec<u8>) -> Result<(), Box<Error + Syn
 
 /// Deserializes an `HSTORE` value.
 #[inline]
-pub fn hstore_from_sql<'a>(mut buf: &'a [u8])
-                           -> Result<HstoreEntries<'a>, Box<Error + Sync + Send>> {
-    let count = try!(buf.read_i32::<BigEndian>());
+pub fn hstore_from_sql<'a>(
+    mut buf: &'a [u8],
+) -> Result<HstoreEntries<'a>, StdBox<Error + Sync + Send>> {
+    let count = buf.read_i32::<BigEndian>()?;
     if count < 0 {
         return Err("invalid entry count".into());
     }
@@ -222,10 +227,10 @@ pub struct HstoreEntries<'a> {
 
 impl<'a> FallibleIterator for HstoreEntries<'a> {
     type Item = (&'a str, Option<&'a str>);
-    type Error = Box<Error + Sync + Send>;
+    type Error = StdBox<Error + Sync + Send>;
 
     #[inline]
-    fn next(&mut self) -> Result<Option<(&'a str, Option<&'a str>)>, Box<Error + Sync + Send>> {
+    fn next(&mut self) -> Result<Option<(&'a str, Option<&'a str>)>, StdBox<Error + Sync + Send>> {
         if self.remaining == 0 {
             if !self.buf.is_empty() {
                 return Err("invalid buffer size".into());
@@ -235,20 +240,20 @@ impl<'a> FallibleIterator for HstoreEntries<'a> {
 
         self.remaining -= 1;
 
-        let key_len = try!(self.buf.read_i32::<BigEndian>());
+        let key_len = self.buf.read_i32::<BigEndian>()?;
         if key_len < 0 {
             return Err("invalid key length".into());
         }
         let (key, buf) = self.buf.split_at(key_len as usize);
-        let key = try!(str::from_utf8(key));
+        let key = str::from_utf8(key)?;
         self.buf = buf;
 
-        let value_len = try!(self.buf.read_i32::<BigEndian>());
+        let value_len = self.buf.read_i32::<BigEndian>()?;
         let value = if value_len < 0 {
             None
         } else {
             let (value, buf) = self.buf.split_at(value_len as usize);
-            let value = try!(str::from_utf8(value));
+            let value = str::from_utf8(value)?;
             self.buf = buf;
             Some(value)
         };
@@ -265,10 +270,15 @@ impl<'a> FallibleIterator for HstoreEntries<'a> {
 
 /// Serializes a `VARBIT` or `BIT` value.
 #[inline]
-pub fn varbit_to_sql<I>(len: usize, v: I, buf: &mut Vec<u8>) -> Result<(), Box<Error + Sync + Send>>
-    where I: Iterator<Item = u8>
+pub fn varbit_to_sql<I>(
+    len: usize,
+    v: I,
+    buf: &mut Vec<u8>,
+) -> Result<(), StdBox<Error + Sync + Send>>
+where
+    I: Iterator<Item = u8>,
 {
-    let len = try!(i32::from_usize(len));
+    let len = i32::from_usize(len)?;
     buf.write_i32::<BigEndian>(len).unwrap();
 
     for byte in v {
@@ -280,8 +290,8 @@ pub fn varbit_to_sql<I>(len: usize, v: I, buf: &mut Vec<u8>) -> Result<(), Box<E
 
 /// Deserializes a `VARBIT` or `BIT` value.
 #[inline]
-pub fn varbit_from_sql<'a>(mut buf: &'a [u8]) -> Result<Varbit<'a>, Box<Error + Sync + Send>> {
-    let len = try!(buf.read_i32::<BigEndian>());
+pub fn varbit_from_sql<'a>(mut buf: &'a [u8]) -> Result<Varbit<'a>, StdBox<Error + Sync + Send>> {
+    let len = buf.read_i32::<BigEndian>()?;
     if len < 0 {
         return Err("invalid varbit length".into());
     }
@@ -328,8 +338,8 @@ pub fn timestamp_to_sql(v: i64, buf: &mut Vec<u8>) {
 ///
 /// The value represents the number of microseconds since midnight, January 1st, 2000.
 #[inline]
-pub fn timestamp_from_sql(mut buf: &[u8]) -> Result<i64, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i64::<BigEndian>());
+pub fn timestamp_from_sql(mut buf: &[u8]) -> Result<i64, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i64::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid message length".into());
     }
@@ -348,8 +358,8 @@ pub fn date_to_sql(v: i32, buf: &mut Vec<u8>) {
 ///
 /// The value represents the number of days since January 1st, 2000.
 #[inline]
-pub fn date_from_sql(mut buf: &[u8]) -> Result<i32, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i32::<BigEndian>());
+pub fn date_from_sql(mut buf: &[u8]) -> Result<i32, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i32::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid message length".into());
     }
@@ -368,8 +378,8 @@ pub fn time_to_sql(v: i64, buf: &mut Vec<u8>) {
 ///
 /// The value represents the number of microseconds since midnight.
 #[inline]
-pub fn time_from_sql(mut buf: &[u8]) -> Result<i64, Box<Error + Sync + Send>> {
-    let v = try!(buf.read_i64::<BigEndian>());
+pub fn time_from_sql(mut buf: &[u8]) -> Result<i64, StdBox<Error + Sync + Send>> {
+    let v = buf.read_i64::<BigEndian>()?;
     if !buf.is_empty() {
         return Err("invalid message length".into());
     }
@@ -384,7 +394,7 @@ pub fn macaddr_to_sql(v: [u8; 6], buf: &mut Vec<u8>) {
 
 /// Deserializes a `MACADDR` value.
 #[inline]
-pub fn macaddr_from_sql(buf: &[u8]) -> Result<[u8; 6], Box<Error + Sync + Send>> {
+pub fn macaddr_from_sql(buf: &[u8]) -> Result<[u8; 6], StdBox<Error + Sync + Send>> {
     if buf.len() != 6 {
         return Err("invalid message length".into());
     }
@@ -401,7 +411,7 @@ pub fn uuid_to_sql(v: [u8; 16], buf: &mut Vec<u8>) {
 
 /// Deserializes a `UUID` value.
 #[inline]
-pub fn uuid_from_sql(buf: &[u8]) -> Result<[u8; 16], Box<Error + Sync + Send>> {
+pub fn uuid_from_sql(buf: &[u8]) -> Result<[u8; 16], StdBox<Error + Sync + Send>> {
     if buf.len() != 16 {
         return Err("invalid message length".into());
     }
@@ -412,16 +422,18 @@ pub fn uuid_from_sql(buf: &[u8]) -> Result<[u8; 16], Box<Error + Sync + Send>> {
 
 /// Serializes an array value.
 #[inline]
-pub fn array_to_sql<T, I, J, F>(dimensions: I,
-                                has_nulls: bool,
-                                element_type: Oid,
-                                elements: J,
-                                mut serializer: F,
-                                buf: &mut Vec<u8>)
-                                -> Result<(), Box<Error + Sync + Send>>
-    where I: IntoIterator<Item = ArrayDimension>,
-          J: IntoIterator<Item = T>,
-          F: FnMut(T, &mut Vec<u8>) -> Result<IsNull, Box<Error + Sync + Send>>
+pub fn array_to_sql<T, I, J, F>(
+    dimensions: I,
+    has_nulls: bool,
+    element_type: Oid,
+    elements: J,
+    mut serializer: F,
+    buf: &mut Vec<u8>,
+) -> Result<(), StdBox<Error + Sync + Send>>
+where
+    I: IntoIterator<Item = ArrayDimension>,
+    J: IntoIterator<Item = T>,
+    F: FnMut(T, &mut Vec<u8>) -> Result<IsNull, StdBox<Error + Sync + Send>>,
 {
     let dimensions_idx = buf.len();
     buf.extend_from_slice(&[0; 4]);
@@ -435,13 +447,13 @@ pub fn array_to_sql<T, I, J, F>(dimensions: I,
         buf.write_i32::<BigEndian>(dimension.lower_bound).unwrap();
     }
 
-    let num_dimensions = try!(i32::from_usize(num_dimensions));
+    let num_dimensions = i32::from_usize(num_dimensions)?;
     (&mut buf[dimensions_idx..dimensions_idx + 4])
         .write_i32::<BigEndian>(num_dimensions)
         .unwrap();
 
     for element in elements {
-        try!(write_nullable(|buf| serializer(element, buf), buf));
+        write_nullable(|buf| serializer(element, buf), buf)?;
     }
 
     Ok(())
@@ -449,22 +461,22 @@ pub fn array_to_sql<T, I, J, F>(dimensions: I,
 
 /// Deserializes an array value.
 #[inline]
-pub fn array_from_sql<'a>(mut buf: &'a [u8]) -> Result<Array<'a>, Box<Error + Sync + Send>> {
-    let dimensions = try!(buf.read_i32::<BigEndian>());
+pub fn array_from_sql<'a>(mut buf: &'a [u8]) -> Result<Array<'a>, StdBox<Error + Sync + Send>> {
+    let dimensions = buf.read_i32::<BigEndian>()?;
     if dimensions < 0 {
         return Err("invalid dimension count".into());
     }
-    let has_nulls = try!(buf.read_i32::<BigEndian>()) != 0;
-    let element_type = try!(buf.read_u32::<BigEndian>());
+    let has_nulls = buf.read_i32::<BigEndian>()? != 0;
+    let element_type = buf.read_u32::<BigEndian>()?;
 
     let mut r = buf;
     let mut elements = 1i32;
     for _ in 0..dimensions {
-        let len = try!(r.read_i32::<BigEndian>());
+        let len = r.read_i32::<BigEndian>()?;
         if len < 0 {
             return Err("invalid dimension size".into());
         }
-        let _lower_bound = try!(r.read_i32::<BigEndian>());
+        let _lower_bound = r.read_i32::<BigEndian>()?;
         elements = match elements.checked_mul(len) {
             Some(elements) => elements,
             None => return Err("too many array elements".into()),
@@ -527,16 +539,16 @@ pub struct ArrayDimensions<'a>(&'a [u8]);
 
 impl<'a> FallibleIterator for ArrayDimensions<'a> {
     type Item = ArrayDimension;
-    type Error = Box<Error + Sync + Send>;
+    type Error = StdBox<Error + Sync + Send>;
 
     #[inline]
-    fn next(&mut self) -> Result<Option<ArrayDimension>, Box<Error + Sync + Send>> {
+    fn next(&mut self) -> Result<Option<ArrayDimension>, StdBox<Error + Sync + Send>> {
         if self.0.is_empty() {
             return Ok(None);
         }
 
-        let len = try!(self.0.read_i32::<BigEndian>());
-        let lower_bound = try!(self.0.read_i32::<BigEndian>());
+        let len = self.0.read_i32::<BigEndian>()?;
+        let lower_bound = self.0.read_i32::<BigEndian>()?;
 
         Ok(Some(ArrayDimension {
             len: len,
@@ -569,10 +581,10 @@ pub struct ArrayValues<'a> {
 
 impl<'a> FallibleIterator for ArrayValues<'a> {
     type Item = Option<&'a [u8]>;
-    type Error = Box<Error + Sync + Send>;
+    type Error = StdBox<Error + Sync + Send>;
 
     #[inline]
-    fn next(&mut self) -> Result<Option<Option<&'a [u8]>>, Box<Error + Sync + Send>> {
+    fn next(&mut self) -> Result<Option<Option<&'a [u8]>>, StdBox<Error + Sync + Send>> {
         if self.remaining == 0 {
             if !self.buf.is_empty() {
                 return Err("invalid message length".into());
@@ -581,7 +593,7 @@ impl<'a> FallibleIterator for ArrayValues<'a> {
         }
         self.remaining -= 1;
 
-        let len = try!(self.buf.read_i32::<BigEndian>());
+        let len = self.buf.read_i32::<BigEndian>()?;
         let val = if len < 0 {
             None
         } else {
@@ -610,24 +622,26 @@ pub fn empty_range_to_sql(buf: &mut Vec<u8>) {
 }
 
 /// Serializes a range value.
-pub fn range_to_sql<F, G>(lower: F,
-                          upper: G,
-                          buf: &mut Vec<u8>)
-                          -> Result<(), Box<Error + Sync + Send>>
-    where F: FnOnce(&mut Vec<u8>) -> Result<RangeBound<IsNull>, Box<Error + Sync + Send>>,
-          G: FnOnce(&mut Vec<u8>) -> Result<RangeBound<IsNull>, Box<Error + Sync + Send>>
+pub fn range_to_sql<F, G>(
+    lower: F,
+    upper: G,
+    buf: &mut Vec<u8>,
+) -> Result<(), StdBox<Error + Sync + Send>>
+where
+    F: FnOnce(&mut Vec<u8>) -> Result<RangeBound<IsNull>, StdBox<Error + Sync + Send>>,
+    G: FnOnce(&mut Vec<u8>) -> Result<RangeBound<IsNull>, StdBox<Error + Sync + Send>>,
 {
     let tag_idx = buf.len();
     buf.push(0);
     let mut tag = 0;
 
-    match try!(write_bound(lower, buf)) {
+    match write_bound(lower, buf)? {
         RangeBound::Inclusive(()) => tag |= RANGE_LOWER_INCLUSIVE,
         RangeBound::Exclusive(()) => {}
         RangeBound::Unbounded => tag |= RANGE_LOWER_UNBOUNDED,
     }
 
-    match try!(write_bound(upper, buf)) {
+    match write_bound(upper, buf)? {
         RangeBound::Inclusive(()) => tag |= RANGE_UPPER_INCLUSIVE,
         RangeBound::Exclusive(()) => {}
         RangeBound::Unbounded => tag |= RANGE_UPPER_UNBOUNDED,
@@ -638,13 +652,17 @@ pub fn range_to_sql<F, G>(lower: F,
     Ok(())
 }
 
-fn write_bound<F>(bound: F, buf: &mut Vec<u8>) -> Result<RangeBound<()>, Box<Error + Sync + Send>>
-    where F: FnOnce(&mut Vec<u8>) -> Result<RangeBound<IsNull>, Box<Error + Sync + Send>>
+fn write_bound<F>(
+    bound: F,
+    buf: &mut Vec<u8>,
+) -> Result<RangeBound<()>, StdBox<Error + Sync + Send>>
+where
+    F: FnOnce(&mut Vec<u8>) -> Result<RangeBound<IsNull>, StdBox<Error + Sync + Send>>,
 {
     let base = buf.len();
     buf.extend_from_slice(&[0; 4]);
 
-    let (null, ret) = match try!(bound(buf)) {
+    let (null, ret) = match bound(buf)? {
         RangeBound::Inclusive(null) => (Some(null), RangeBound::Inclusive(())),
         RangeBound::Exclusive(null) => (Some(null), RangeBound::Exclusive(())),
         RangeBound::Unbounded => (None, RangeBound::Unbounded),
@@ -653,10 +671,12 @@ fn write_bound<F>(bound: F, buf: &mut Vec<u8>) -> Result<RangeBound<()>, Box<Err
     match null {
         Some(null) => {
             let len = match null {
-                IsNull::No => try!(i32::from_usize(buf.len() - base - 4)),
+                IsNull::No => i32::from_usize(buf.len() - base - 4)?,
                 IsNull::Yes => -1,
             };
-            (&mut buf[base..base + 4]).write_i32::<BigEndian>(len).unwrap();
+            (&mut buf[base..base + 4])
+                .write_i32::<BigEndian>(len)
+                .unwrap();
         }
         None => buf.truncate(base),
     }
@@ -676,8 +696,8 @@ pub enum RangeBound<T> {
 
 /// Deserializes a range value.
 #[inline]
-pub fn range_from_sql<'a>(mut buf: &'a [u8]) -> Result<Range<'a>, Box<Error + Sync + Send>> {
-    let tag = try!(buf.read_u8());
+pub fn range_from_sql<'a>(mut buf: &'a [u8]) -> Result<Range<'a>, StdBox<Error + Sync + Send>> {
+    let tag = buf.read_u8()?;
 
     if tag == RANGE_EMPTY {
         if !buf.is_empty() {
@@ -686,8 +706,8 @@ pub fn range_from_sql<'a>(mut buf: &'a [u8]) -> Result<Range<'a>, Box<Error + Sy
         return Ok(Range::Empty);
     }
 
-    let lower = try!(read_bound(&mut buf, tag, RANGE_LOWER_UNBOUNDED, RANGE_LOWER_INCLUSIVE));
-    let upper = try!(read_bound(&mut buf, tag, RANGE_UPPER_UNBOUNDED, RANGE_UPPER_INCLUSIVE));
+    let lower = read_bound(&mut buf, tag, RANGE_LOWER_UNBOUNDED, RANGE_LOWER_INCLUSIVE)?;
+    let upper = read_bound(&mut buf, tag, RANGE_UPPER_UNBOUNDED, RANGE_UPPER_INCLUSIVE)?;
 
     if !buf.is_empty() {
         return Err("invalid message size".into());
@@ -697,15 +717,16 @@ pub fn range_from_sql<'a>(mut buf: &'a [u8]) -> Result<Range<'a>, Box<Error + Sy
 }
 
 #[inline]
-fn read_bound<'a>(buf: &mut &'a [u8],
-                  tag: u8,
-                  unbounded: u8,
-                  inclusive: u8)
-                  -> Result<RangeBound<Option<&'a [u8]>>, Box<Error + Sync + Send>> {
+fn read_bound<'a>(
+    buf: &mut &'a [u8],
+    tag: u8,
+    unbounded: u8,
+    inclusive: u8,
+) -> Result<RangeBound<Option<&'a [u8]>>, StdBox<Error + Sync + Send>> {
     if tag & unbounded != 0 {
         Ok(RangeBound::Unbounded)
     } else {
-        let len = try!(buf.read_i32::<BigEndian>());
+        let len = buf.read_i32::<BigEndian>()?;
         let value = if len < 0 {
             None
         } else {
@@ -734,6 +755,190 @@ pub enum Range<'a> {
     Nonempty(RangeBound<Option<&'a [u8]>>, RangeBound<Option<&'a [u8]>>),
 }
 
+/// Serializes a point value.
+#[inline]
+pub fn point_to_sql(x: f64, y: f64, buf: &mut Vec<u8>) {
+    buf.write_f64::<BigEndian>(x).unwrap();
+    buf.write_f64::<BigEndian>(y).unwrap();
+}
+
+/// Deserializes a point value.
+#[inline]
+pub fn point_from_sql(mut buf: &[u8]) -> Result<Point, StdBox<Error + Sync + Send>> {
+    let x = buf.read_f64::<BigEndian>()?;
+    let y = buf.read_f64::<BigEndian>()?;
+    if !buf.is_empty() {
+        return Err("invalid buffer size".into());
+    }
+    Ok(Point { x: x, y: y })
+}
+
+/// A Postgres point.
+#[derive(Copy, Clone)]
+pub struct Point {
+    x: f64,
+    y: f64,
+}
+
+impl Point {
+    /// Returns the x coordinate of the point.
+    #[inline]
+    pub fn x(&self) -> f64 {
+        self.x
+    }
+
+    /// Returns the y coordinate of the point.
+    #[inline]
+    pub fn y(&self) -> f64 {
+        self.y
+    }
+}
+
+/// Serializes a box value.
+#[inline]
+pub fn box_to_sql(x1: f64, y1: f64, x2: f64, y2: f64, buf: &mut Vec<u8>) {
+    buf.write_f64::<BigEndian>(x1).unwrap();
+    buf.write_f64::<BigEndian>(y1).unwrap();
+    buf.write_f64::<BigEndian>(x2).unwrap();
+    buf.write_f64::<BigEndian>(y2).unwrap();
+}
+
+/// Deserializes a box value.
+#[inline]
+pub fn box_from_sql(mut buf: &[u8]) -> Result<Box, StdBox<Error + Sync + Send>> {
+    let x1 = buf.read_f64::<BigEndian>()?;
+    let y1 = buf.read_f64::<BigEndian>()?;
+    let x2 = buf.read_f64::<BigEndian>()?;
+    let y2 = buf.read_f64::<BigEndian>()?;
+    if !buf.is_empty() {
+        return Err("invalid buffer size".into());
+    }
+    Ok(Box {
+        upper_right: Point { x: x1, y: y1 },
+        lower_left: Point { x: x2, y: y2 },
+    })
+}
+
+/// A Postgres box.
+#[derive(Copy, Clone)]
+pub struct Box {
+    upper_right: Point,
+    lower_left: Point,
+}
+
+impl Box {
+    /// Returns the upper right corner of the box.
+    #[inline]
+    pub fn upper_right(&self) -> Point {
+        self.upper_right
+    }
+
+    /// Returns the lower left corner of the box.
+    #[inline]
+    pub fn lower_left(&self) -> Point {
+        self.lower_left
+    }
+}
+
+/// Serializes a Postgres path.
+#[inline]
+pub fn path_to_sql<I>(
+    closed: bool,
+    points: I,
+    buf: &mut Vec<u8>,
+) -> Result<(), StdBox<Error + Sync + Send>>
+where
+    I: IntoIterator<Item = (f64, f64)>,
+{
+    buf.push(closed as u8);
+    let points_idx = buf.len();
+    buf.extend_from_slice(&[0; 4]);
+
+    let mut num_points = 0;
+    for (x, y) in points {
+        num_points += 1;
+        buf.write_f64::<BigEndian>(x).unwrap();
+        buf.write_f64::<BigEndian>(y).unwrap();
+    }
+
+    let num_points = i32::from_usize(num_points)?;
+    (&mut buf[points_idx..])
+        .write_i32::<BigEndian>(num_points)
+        .unwrap();
+
+    Ok(())
+}
+
+/// Deserializes a Postgres path.
+#[inline]
+pub fn path_from_sql<'a>(mut buf: &'a [u8]) -> Result<Path<'a>, StdBox<Error + Sync + Send>> {
+    let closed = buf.read_u8()? != 0;
+    let points = buf.read_i32::<BigEndian>()?;
+
+    Ok(Path {
+        closed: closed,
+        points: points,
+        buf: buf,
+    })
+}
+
+/// A Postgres point.
+pub struct Path<'a> {
+    closed: bool,
+    points: i32,
+    buf: &'a [u8],
+}
+
+impl<'a> Path<'a> {
+    /// Determines if the path is closed or open.
+    #[inline]
+    pub fn closed(&self) -> bool {
+        self.closed
+    }
+
+    /// Returns an iterator over the points in the path.
+    #[inline]
+    pub fn points(&self) -> PathPoints<'a> {
+        PathPoints {
+            remaining: self.points,
+            buf: self.buf,
+        }
+    }
+}
+
+/// An iterator over the points of a Postgres path.
+pub struct PathPoints<'a> {
+    remaining: i32,
+    buf: &'a [u8],
+}
+
+impl<'a> FallibleIterator for PathPoints<'a> {
+    type Item = Point;
+    type Error = StdBox<Error + Sync + Send>;
+
+    #[inline]
+    fn next(&mut self) -> Result<Option<Point>, StdBox<Error + Sync + Send>> {
+        if self.remaining == 0 {
+            if !self.buf.is_empty() {
+                return Err("invalid message length".into());
+            }
+            return Ok(None);
+        }
+        self.remaining -= 1;
+
+        let x = self.buf.read_f64::<BigEndian>()?;
+        let y = self.buf.read_f64::<BigEndian>()?;
+
+        Ok(Some(Point { x: x, y: y }))
+    }
+
+    #[inline]
+    fn size_hint(&self) -> (usize, Option<usize>) {
+        let len = self.remaining as usize;
+        (len, Some(len))
+    }
+}
+
 #[cfg(test)]
 mod test {
     use std::collections::HashMap;
@@ -796,8 +1001,13 @@ mod test {
 
         let mut buf = vec![];
         hstore_to_sql(map.iter().map(|(&k, &v)| (k, v)), &mut buf).unwrap();
-        assert_eq!(hstore_from_sql(&buf).unwrap().collect::<HashMap<_, _>>().unwrap(),
-                   map);
+        assert_eq!(
+            hstore_from_sql(&buf)
+                .unwrap()
+                .collect::<HashMap<_, _>>()
+                .unwrap(),
+            map
+        );
     }
 
     #[test]
@@ -814,32 +1024,33 @@ mod test {
 
     #[test]
     fn array() {
-        let dimensions = [ArrayDimension {
-                              len: 1,
-                              lower_bound: 10,
-                          },
-                          ArrayDimension {
-                              len: 2,
-                              lower_bound: 0,
-                          }];
+        let dimensions = [
+            ArrayDimension {
+                len: 1,
+                lower_bound: 10,
+            },
+            ArrayDimension {
+                len: 2,
+                lower_bound: 0,
+            },
+        ];
         let values = [None, Some(&b"hello"[..])];
 
         let mut buf = vec![];
-        array_to_sql(dimensions.iter().cloned(),
-                     true,
-                     10,
-                     values.iter().cloned(),
-                     |v, buf| {
-            match v {
+        array_to_sql(
+            dimensions.iter().cloned(),
+            true,
+            10,
+            values.iter().cloned(),
+            |v, buf| match v {
                 Some(v) => {
                     buf.extend_from_slice(v);
                     Ok(IsNull::No)
                 }
                 None => Ok(IsNull::Yes),
-            }
-        },
-                     &mut buf)
-            .unwrap();
+            },
+            &mut buf,
+        ).unwrap();
 
         let array = array_from_sql(&buf).unwrap();
         assert_eq!(array.has_nulls(), true);
